ExcusesItem

Struct ExcusesItem 

pub struct ExcusesItem {
    pub maintainer: Option<String>,
    pub is_candidate: bool,
    pub new_version: Option<PackageVersion>,
    pub old_version: Option<PackageVersion>,
    pub item_name: String,
    pub source: PackageName,
    pub invalidated_by_other_package: Option<bool>,
    pub component: Option<Component>,
    pub missing_builds: Option<MissingBuilds>,
    pub policy_info: Option<PolicyInfo>,
    pub excuses: Vec<String>,
    pub migration_policy_verdict: Verdict,
}
A source package’s excuses

Fields

maintainer: Option<String>

Maintainer of the package

is_candidate: bool

The item is a candidate for migration

new_version: Option<PackageVersion>

Version in the source suite, i.e., the version to migrate

If the value is None, the package is being removed.

old_version: Option<PackageVersion>

Version in the target suite

If the value is None, the package is not yet available in the target suite.

item_name: String

Migration item name

source: PackageName

Source package name

invalidated_by_other_package: Option<bool>

Migration is blocked by another package

component: Option<Component>

Component of the source package

missing_builds: Option<MissingBuilds>

Missing builds

policy_info: Option<PolicyInfo>

Policy info

excuses: Vec<String>

The excuses

migration_policy_verdict: Verdict

Combined verdict

Implementations

Source

impl ExcusesItem

pub fn is_removal(&self) -> bool

Excuses item refers to package removal

pub fn is_binnmu(&self) -> bool

Excuses item refers to a binNMU

pub fn binnmu_arch(&self) -> Option<Architecture>

Get architecture of the binNMU or None

pub fn is_from_pu(&self) -> bool

Excuses item refers to an item in (stable) proposed-updates

pub fn is_from_tpu(&self) -> bool

Excuses item refers to an item in testing-proposed-updates